0.5 (2020-11-30)
----------------

- Fixed compatibility with glue-core 1.0. [#77]

- Fixed a bug that caused altitude unit to not work correctly on Windows. [#74]

- Fixed a bug related to reloading sessions with WWT viewers. [#76]

- Included a save button to save the current view to the first slide of a tour. [#70, #72, #73]

- Added initial support for using glue-wwt in Jupyter. [#64]

0.4 (2019-06-23)
----------------

- Fixed bug with layer centering when NaN values are present. [#55]

- Fixed issues with layer visibility. [#52]

- Fixed bug that caused remonving layers to not work. [#56]

- Fixed issue with viewer options not being set correctly when loading from a session. [#52]

- Fixed compatibility with the latest developer version of glue. [#52]

- Fixed issue with automatic installation of dependencies. [#52]

0.3 (2019-02-27)
----------------

- Added support for showing data on the surface of celestial bodies as well as
  in the 3D Solar System/Milky Way/Universe view. [#40, #42]

- Added support for color-coding and changing point size based on attributes
  (requires PyWWT 0.6 or later). [#44]

0.2 (2018-12-29)
----------------

- Add a Save button to save the current view to a file. [#38]

- Make use of PyWWT. [#32, #35]

- Change default foreground and background imagery. [#29]

- Fix compatibility with latest version of glue. [#25]

- Allow world coordinates to be used for the RA/Dec. [#21]

0.1 (2017-08-23)
----------------

- Initial release
